/* FONTS */
@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-Regular.ttf');
    font-style: normal;
    font-weight: 400;
}

@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-Italic.ttf');
    font-style: italic;
    font-weight: 400;
}

@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-Bold.ttf');
    font-style: normal;
    font-weight: 700;
}

@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-BoldItalic.ttf');
    font-style: italic;
    font-weight: 700;
}

@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-Light.ttf');
    font-style: normal;
    font-weight: 300;
}

@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-LightItalic.ttf');
    font-style: italic;
    font-weight: 300;
}

.research-interface {
    font-family: 'Nunito Sans', sans-serif;
}

.research-interface a {
    color: #009c94;
    text-decoration: none;
}
.research-interface a:hover {
    color: #005955;
}

.ddm-btn {
    background-color: #1a1a1a;
    color: white !important;
    border-radius: 4px;
    border: 2px solid #1a1a1a;
    padding: 5px 15px !important;
    font-size: 0.9rem;
    text-decoration: none;
}
.ddm-btn:hover {
    border-color: #009c94;
}

.ddm-btn-red {
    background-color: #9a0000;
    border: 2px solid #9a0000;
}