{% extends 'ddm/project_admin/base.html' %}

{% block page_title %}Password Changed{% endblock %}

{% block main_heading %}Password Successfully Changed{% endblock %}

{% block main_body %}
<div>
  <p>Your password change was successful!</p>
  <p><a href="{% url 'ddm-profile-detail' %}">Back to your profile</a></p>
  <p><a href="{% url 'project-list' %}">To your projects</a></p>
</div>
{% endblock %}

{% block breadcrumbs %}
<a href="{% url 'ddm-profile-detail' %}">Profile</a> /
Password Changed
{% endblock %}
