{% extends "ddm/public/base.html" %}
{% load static i18n %}

{% block content %}
<div>

  <div>
    {% if object.intro_text == None %}
    <h1>{% translate "Welcome to this study!" %}</h1>
    <p>{% translate "Please define a description and welcome text for this project in the Project Hub." %}</p>
    {% else %}
    {{ object.intro_text | safe }}
    {% endif %}
  </div>

  <form method="POST">
    {% csrf_token %}
    <input
        class="flow-btn"
        type="submit"
        value="{% translate 'Continue&nbsp;&nbsp;&#8250;' %}"
    />
  </form>
</div>
{% endblock content %}
