{% extends 'ddm/project_admin/base.html' %}

{% block page_title %}Profile Overview{% endblock %}

{% block main_heading %}Profile Overview{% endblock %}

{% block main_body %}
<div class="ddm-admin-section">
  <div class="ddm-admin-section-body">
    <div class="row">
      <div class="col-3">Username:</div>
      <div class="col">{{ object.username }}</div>
    </div>
    <div class="row">
      <div class="col-3">Email:</div>
      <div class="col">{{ object.email }}</div>
    </div>
    <div class="row pb-3">
      <a href="{% url 'ddm-change-pw' %}">Change Password</a>
    </div>
    <div class="row">
      <div class="col-3">Profile Created:</div>
      <div class="col">{{ profile.created|date }}</div>
    </div>
    <div class="row pt-3">
      <a href="{% url 'project-list' %}">To my projects</a>
    </div>
    <div class="row">
      <a href="{% url 'ddm-logout' %}">Logout</a>
    </div>
  </div>
</div>
{% endblock %}

{% block breadcrumbs %}
Profile
{% endblock %}
